const jqueryDeprecations = ({
  dialog,
  settings,
  deprecationError
}) => {
  const deprecatedOptions = ["appendTo", "classes", "draggable", "hide", "position", "resizable", "show"];
  Object.keys(settings).filter((key) => deprecatedOptions.includes(key)).forEach((key) => {
    deprecationError({
      message: `The "${key}" Drupal.dialog option is deprecated and has no effect.`
    });
  });
  return dialog;
};
class DrupalDialogEvent extends Event {
  constructor(type, dialog, settings) {
    super(`dialog:${type}`, { bubbles: true });
    this.dialog = dialog;
    this.settings = settings;
  }
}
function _createElementFromString(str) {
  const tempDiv = document.createElement("div");
  tempDiv.innerHTML = str.trim();
  const el = tempDiv.firstElementChild;
  if (el instanceof HTMLElement) {
    document.body.appendChild(el);
    return el;
  }
  document.body.appendChild(tempDiv);
  return tempDiv;
}
(function(Drupal, drupalSettings) {
  drupalSettings.dialog = {
    autoOpen: true,
    buttonClass: "button",
    buttonPrimaryClass: "button--primary",
    close: (event) => {
      const target = event.target;
      target == null ? void 0 : target.dispatchEvent(
        new CustomEvent("dialog-close")
      );
    }
  };
  Drupal.dialog = function(element, options) {
    const settings = { ...drupalSettings.dialog, ...options };
    let domElement;
    if (typeof element === "string") {
      domElement = _createElementFromString(element);
    } else {
      domElement = element;
    }
    let dialog = document.createElement("dialog");
    dialog.classList.add("drupal-dialog");
    dialog.setAttribute("draggable", "true");
    dialog.append(Drupal.theme("dialog", { domElement, ...settings }));
    document.body.append(dialog);
    domElement.dispatchEvent(
      new DrupalDialogEvent("beforecreate", dialog, settings)
    );
    const observer = new MutationObserver((mutationsList) => {
      for (const mutation of mutationsList) {
        if (mutation.attributeName === "open") {
          if (dialog.hasAttribute("open")) {
            domElement.style.display = "block";
            setTimeout(() => {
              domElement.dispatchEvent(
                new DrupalDialogEvent("aftercreate", dialog, settings)
              );
            }, 0);
          }
        }
      }
    });
    observer.observe(dialog, { attributes: true });
    const closeDialog = () => {
      var _a;
      domElement.dispatchEvent(
        new DrupalDialogEvent("beforeclose", dialog, settings)
      );
      dialog.close();
      Drupal.detachBehaviors(domElement);
      if ((_a = drupalSettings == null ? void 0 : drupalSettings.dialog) == null ? void 0 : _a.close) {
        drupalSettings.dialog.close({ ...new Event("closeDialog"), target: domElement });
      }
      setTimeout(() => {
        domElement.dispatchEvent(
          new DrupalDialogEvent("afterclose", dialog, settings)
        );
      }, 0);
    };
    dialog.addEventListener("dialog-close", closeDialog);
    dialog.addEventListener("close", closeDialog);
    dialog.addEventListener("dialog-remove", () => {
      dialog.remove();
    });
    dialog = jqueryDeprecations({
      dialog,
      settings,
      deprecationError: Drupal.deprecationError
    });
    if (settings.closeOnEscape === false) {
      dialog.addEventListener("cancel", (event) => {
        event.preventDefault();
      });
      dialog.addEventListener("keydown", (event) => {
        if (event.key === "Escape") {
          event.preventDefault();
        }
      });
    }
    if (settings.autoOpen === true) {
      dialog == null ? void 0 : dialog[(settings == null ? void 0 : settings.modal) ? "showModal" : "show"]();
    }
    const styleProps = [
      "height",
      "width",
      "maxHeight",
      "maxWidth",
      "minHeight",
      "minWidth",
      "zIndex"
    ];
    styleProps.forEach((prop) => {
      if (settings[prop]) {
        dialog.style[prop === "zIndex" ? "zIndex" : prop] = `${settings[prop]}${prop === "zIndex" ? "" : "px"}`;
      }
    });
    return dialog;
  };
})(window.Drupal, window.drupalSettings);
