(function(Drupal) {
  Drupal.behaviors.dialog = {
    attach(_context, settings) {
      var _a;
      if (!document.querySelector("#drupal-modal")) {
        document.body.insertAdjacentHTML(
          "beforeend",
          '<div id="drupal-modal" style="display:none"></div>'
        );
      }
      const originalClose = (_a = settings == null ? void 0 : settings.dialog) == null ? void 0 : _a.close;
      if (settings && typeof settings.dialog === "object" && settings.dialog !== null && originalClose) {
        settings.dialog.close = (event, ...args) => {
          var _a2;
          originalClose.apply(settings.dialog, [event, ...args]);
          (_a2 = event.target) == null ? void 0 : _a2.dispatchEvent(new CustomEvent("dialog-remove", { bubbles: true }));
        };
      }
    },
    prepareDialogButtons(dialog) {
      const buttons = [];
      const buttonSelectors = ".form-actions input[type=submit], .form-actions a.button, .form-actions a.action-link";
      const buttonElements = dialog.querySelectorAll(buttonSelectors);
      buttonElements.forEach((button) => {
        if (!(button instanceof HTMLElement)) {
          return;
        }
        button.style.display = "none";
        buttons.push({
          text: button.innerHTML || button.getAttribute("value") || "",
          class: button.getAttribute("class") || "",
          "data-once": button.dataset.once,
          click(e) {
            if (button.tagName === "A") {
              button.click();
            } else {
              ["mousedown", "mouseup", "click"].forEach(
                (event) => button.dispatchEvent(new MouseEvent(event, { bubbles: true }))
              );
            }
            e.preventDefault();
          }
        });
      });
      return buttons;
    }
  };
  Drupal.AjaxCommands.prototype.openDialog = (ajax, response, status) => {
    if (!response.selector) {
      return false;
    }
    let dialog = document.querySelector(response.selector);
    if (!dialog) {
      dialog = document.createElement("div");
      dialog.id = response.selector.replace(/^#/, "");
      document.body.appendChild(dialog);
    }
    if (!ajax.wrapper) {
      ajax.wrapper = dialog.id;
    }
    response.command = "insert";
    response.method = "html";
    ajax.commands.insert(ajax, response, status);
    const createdDialog = Drupal.dialog(dialog, response.dialogOptions);
    if (response.dialogOptions.modal) {
      createdDialog.showModal();
    } else {
      createdDialog.show();
    }
  };
  Drupal.AjaxCommands.prototype.closeDialog = function(_ajax, response) {
    const dialog = document.querySelector(response.selector);
    if (dialog) {
      Drupal.dialog(dialog).close();
      if (!response.persist) {
        dialog.dispatchEvent(
          new CustomEvent("dialog-remove", {
            bubbles: true
          })
        );
      }
    }
  };
})(window.Drupal);
