(function(Drupal) {
  Drupal.theme.dialog = ({ buttons, closeText, domElement, title }) => {
    const dialogWrapper = document.createElement("div");
    dialogWrapper.classList.add("drupal-dialog__wrapper");
    dialogWrapper.append(Drupal.theme("dialogHeader", title ?? "", closeText ?? "Close"));
    if (domElement) {
      dialogWrapper.append(Drupal.theme("dialogContent", domElement));
    }
    if (buttons) {
      dialogWrapper.append(Drupal.theme("dialogButtons", buttons));
    }
    return dialogWrapper;
  };
  Drupal.theme.dialogHeader = (title, closeText) => {
    const dialogHeaderWrapper = document.createElement("div");
    dialogHeaderWrapper.classList.add("drupal-dialog__header");
    if (title) {
      dialogHeaderWrapper.insertAdjacentHTML(
        "beforeend",
        `<h4 class="drupal-dialog__title">${title}</h4>`
      );
    }
    const button = document.createElement("button");
    button.innerText = Drupal.t(closeText ?? "Close");
    button.classList.add("drupal-dialog__close");
    button.addEventListener("click", () => {
      button.dispatchEvent(
        new CustomEvent("dialog-close", {
          bubbles: true
        })
      );
    });
    dialogHeaderWrapper.append(button);
    return dialogHeaderWrapper;
  };
  Drupal.theme.dialogContent = (content) => {
    const dialogContentWrapper = document.createElement("div");
    dialogContentWrapper.classList.add("drupal-dialog__content");
    dialogContentWrapper.appendChild(content);
    return dialogContentWrapper;
  };
  Drupal.theme.dialogButtons = (buttons) => {
    const dialogButtonsWrapper = document.createElement("div");
    dialogButtonsWrapper.classList.add("drupal-dialog__buttons");
    if (Array.isArray(buttons)) {
      buttons.forEach((button) => {
        const buttonElement = document.createElement("button");
        buttonElement.textContent = button.text ?? "";
        if (button.class) {
          buttonElement.classList.add(...button.class.split(" "));
        }
        if (button.click) {
          buttonElement.addEventListener(
            "click",
            button.click
          );
        }
        dialogButtonsWrapper.appendChild(buttonElement);
      });
    } else if (typeof buttons === "object" && buttons !== null) {
      Object.keys(buttons).forEach((buttonText) => {
        const buttonElement = document.createElement("button");
        buttonElement.textContent = buttonText;
        buttonElement.addEventListener(
          "click",
          buttons[buttonText]
        );
        dialogButtonsWrapper.appendChild(buttonElement);
      });
    }
    return dialogButtonsWrapper;
  };
})(window.Drupal);
