import stringifyObject from 'stringify-object';
import '../dialogTheme';
import '../dialog';
import { testGroups } from './tests';
import { TestCase } from './tests';

let currentEventListeners: Array<{ event: string; handler: EventListener }> =
  [];

const displayMenu = () => {
  const menuWrapper = document.querySelector('.menu-area')!;
  menuWrapper.innerHTML = '';
  const { group: activeGroup, case: activeCase } = Object.fromEntries(
    new URLSearchParams(window.location.search),
  );

  Object.entries(testGroups).forEach(([group, cases]) => {
    const groupBlock = document.createElement('div');
    menuWrapper.appendChild(groupBlock);

    const groupTitle = document.createElement('h6');
    groupTitle.innerText = group.charAt(0).toUpperCase() + group.slice(1);
    groupBlock.appendChild(groupTitle);

    cases.forEach((testCase: TestCase, index: number) => {
      const link = document.createElement('a');
      link.href = `?group=${group}&case=${index}`;
      link.innerText = testCase.options?.title ?? 'Unnamed Case';
      link.style.display = 'block';
      if (group === activeGroup && String(index) === activeCase)
        link.style.color = 'red';
      groupBlock.appendChild(link);
    });
  });
};

const clearEventListeners = () => {
  currentEventListeners.forEach(({ event, handler }) =>
    window.removeEventListener(event, handler),
  );
  currentEventListeners = [];
};

const loadTestCase = (contentWrapper: HTMLElement) => {
  clearEventListeners();
  const { group, case: caseIndex } = Object.fromEntries(
    new URLSearchParams(window.location.search),
  );
  contentWrapper.innerHTML = '';

  if (group && caseIndex !== null && testGroups[group]) {
    const testCase: TestCase = testGroups[group][Number(caseIndex)];
    if (testCase) {
      const block = document.createElement('div');
      const button = document.createElement('button');
      button.innerText = testCase.options?.title ?? 'Open Dialog';
      block.appendChild(button);

      const content = testCase.content
        ? testCase.content
        : Object.assign(document.createElement('div'), {
            innerHTML: '<p>Dialog Content</p>',
          });

      const outputObject = {
        ...testCase,
        content: content instanceof HTMLElement ? content.outerHTML : content,
      };

      const pre = document
        .createElement('code')
        .appendChild(document.createElement('pre'));
      pre.classList.add('code-output');
      const code = document.createElement('code');
      code.innerText = stringifyObject(outputObject, {
        indent: '  ',
        singleQuotes: true,
        inlineCharacterLimit: 30,
        transform: (_object, property, originalResult) => {
          if (property === 'of') {
            return 'window';
          }

          return originalResult;
        }
      });
      pre.appendChild(code);
      block.appendChild(pre);

      if (testCase.events) {
        Object.entries(testCase.events).forEach(([eventName, handler]) => {
          const eventHandler = () => handler?.();
          window.addEventListener(eventName, eventHandler);
          currentEventListeners.push({
            event: eventName,
            handler: eventHandler,
          });
        });
      }

      window.Drupal.deprecationError = ({ message }) => {
        console.warn(`[Deprecation] ${message}`);
      };

      window.Drupal.dialog?.(content, testCase.options);

      button.addEventListener('click', () => {
        const dialog = window.Drupal.dialog?.(
          content,
          testCase.options,
        );
        dialog?.[testCase.options?.modal ? 'showModal' : 'show']();
      });

      contentWrapper.appendChild(block);
    }
  } else {
    contentWrapper.innerHTML = '<p>Select a test case from the menu.</p>';
  }
};

document.addEventListener('DOMContentLoaded', () => {
  const contentWrapper = document.querySelector('.test-area')!;

  displayMenu();
  loadTestCase(contentWrapper as HTMLElement);
});
