export interface TestCase {
  content?: string | HTMLElement;
  options?: DialogOptions;
  events?: {
    'dialog:beforecreate'?: () => void;
    'dialog:aftercreate'?: () => void;
    'dialog:beforeclose'?: () => void;
    'dialog:afterclose'?: () => void;
  };
}

export const testGroups: { [key: string]: TestCase[] } = {
  basic: [
    {
      options: {
        title: 'Basic Dialog',
      },
    },
    {
      options: {
        title: 'Modal Dialog',
        modal: true,
      },
    },
    {
      content: '<i>String Html</i>',
      options: {
        title: 'Dialog With String Content',
      },
    },
    {
      options: {
        title: 'Buttons',
        buttons: [
          {
            text: 'Click me',
            click() {
              alert('button clicked');
            },
          },
          {
            text: 'I will close dialog',
            click(e) {
              e.target.dispatchEvent(
                new CustomEvent('dialog-close', {
                  bubbles: true,
                }),
              );
            },
          },
        ],
      },
    },
    {
      options: {
        title: 'Dialog With different close text',
        closeText: 'Please close me',
      },
    },
  ],

  events: [
    {
      options: {
        title: 'Dialog With Events',
      },
      events: {
        'dialog:beforecreate': () => {
          alert('beforecreate');
        },
        'dialog:aftercreate': () => {
          alert('aftercreate');
        },
        'dialog:beforeclose': () => {
          alert('beforeclose');
        },
        'dialog:afterclose': () => {
          alert('afterclose');
        },
      },
    },
    {
      options: {
        title: 'Auto Open = false',
        autoOpen: false,
      },
    },
    {
      options: {
        title: "Don't close on escape",
        modal: true,
        closeOnEscape: false,
      },
    },
  ],
  deprecation: [
    {
      content: 'Check console',
      options: {
        title: 'Deprecated options',
        appendTo: 'body',
        classes: {
          'ui-dialog': 'test',
        },
        draggable: true,
      },
    },
  ],
  geometry: [
    {
      options: {
        title: 'Height 500',
        height: 500,
      },
    },
    {
      options: {
        title: 'Width 600',
        width: 600,
      },
    },
    {
      options: {
        title: 'Z-Index 1000',
        zIndex: 1000,
      },
    },
    {
      options: {
        title: 'Max Height 500 and Height 1000',
        maxHeight: 500,
        height: 1000,
      },
    },
    {
      options: {
        title: 'Min Height 500',
        minHeight: 500,
      },
    },
  ],
  position: [
    {
      options: {
        title: 'Position center',
        modal: true,
        dialogPosition: {
          reference: document.body,
          options: {
            strategy: 'fixed',
          },
        },
      },
    },
  ],
};
