(function (Drupal) {
  Drupal.behaviors.dialog = {
    attach(_context, settings) {
      if (!document.querySelector('#drupal-modal')) {
        document.body.insertAdjacentHTML(
          'beforeend',
          '<div id="drupal-modal" style="display:none"></div>',
        );
      }

      const originalClose: DialogOptions["close"] = (settings?.dialog as DialogOptions)?.close;

      if (settings && typeof settings.dialog === 'object' && settings.dialog !== null && originalClose) {
        (settings.dialog as DialogOptions).close = (event, ...args) => {
          originalClose.apply(settings.dialog, [event, ...args]);
          event.target?.dispatchEvent(new CustomEvent('dialog-remove', { bubbles: true }));
        };
      }
    },

    prepareDialogButtons(dialog: HTMLElement) {
      const buttons: Array<JQueryUI.DialogButtonOptions> = [];
      const buttonSelectors =
        '.form-actions input[type=submit], .form-actions a.button, .form-actions a.action-link';
      const buttonElements = dialog.querySelectorAll(buttonSelectors);

      buttonElements.forEach((button) => {
        if (!(button instanceof HTMLElement)) {
          return;
        }

        button.style.display = 'none';

        buttons.push({
          text: button.innerHTML || button.getAttribute('value') || '',
          class: button.getAttribute('class') || '',
          'data-once': button.dataset.once,
          click(e) {
            if (button.tagName === 'A') {
              button.click();
            } else {
              ['mousedown', 'mouseup', 'click'].forEach((event) =>
                button.dispatchEvent(new MouseEvent(event, { bubbles: true })),
              );
            }
            e.preventDefault();
          },
        });
      });
      return buttons;
    }

  }

  Drupal.AjaxCommands.prototype.openDialog = (ajax: any, response: any, status: any) => {
    if (!response.selector) {
      return false;
    }
    let dialog = document.querySelector(response.selector);
    console.log('dialog', response.selector, dialog);
    if (!dialog) {
      // Create the element if needed.
      dialog = document.createElement('div');
      dialog.id = response.selector.replace(/^#/, '');
      document.body.appendChild(dialog);
    }
    // Set up the wrapper, if there isn't one.
    if (!ajax.wrapper) {
      ajax.wrapper = dialog.id;
    }

    // Use the ajax.js insert command to populate the dialog contents.
    response.command = 'insert';
    response.method = 'html';
    ajax.commands.insert(ajax, response, status);

    // // Move the buttons to the jQuery UI dialog buttons area.
    // response.dialogOptions = response.dialogOptions || {};
    // if (typeof response.dialogOptions.drupalAutoButtons === 'undefined') {
    //   response.dialogOptions.drupalAutoButtons = true;
    // } else if (response.dialogOptions.drupalAutoButtons === 'false') {
    //   response.dialogOptions.drupalAutoButtons = false;
    // } else {
    //   response.dialogOptions.drupalAutoButtons =
    //     !!response.dialogOptions.drupalAutoButtons;
    // }
    // if (
    //   !response.dialogOptions.buttons &&
    //   response.dialogOptions.drupalAutoButtons
    // ) {
    //   response.dialogOptions.buttons =
    //     Drupal.behaviors.dialog.prepareDialogButtons(dialog);
    // }


    // Open the dialog itself.
    const createdDialog = Drupal.dialog(dialog, response.dialogOptions);
    if (response.dialogOptions.modal) {
      createdDialog.showModal();
    } else {
      createdDialog.show();
    }
  };

  Drupal.AjaxCommands.prototype.closeDialog = function (
    _ajax: any,
    response: any,
  ) {
    const dialog = document.querySelector(response.selector);
    if (dialog) {
      Drupal.dialog(dialog).close();
      if (!response.persist) {
        dialog.dispatchEvent(
          new CustomEvent('dialog-remove', {
            bubbles: true,
          }),
        );
      }
    }
  };

})(window.Drupal);