(function (Drupal) {
  Drupal.theme.dialog = ({ buttons, closeText, domElement, title }) => {
    const dialogWrapper = document.createElement('div');
    dialogWrapper.classList.add('drupal-dialog__wrapper');

    // Add dialog title.
    dialogWrapper.append(Drupal.theme('dialogHeader', title ?? '', closeText ?? 'Close'));

    // Add dialog content.
    if (domElement) {
      dialogWrapper.append(Drupal.theme('dialogContent', domElement));
    }

    // Add dialog buttons.
    if (buttons) {
      dialogWrapper.append(Drupal.theme('dialogButtons', buttons));
    }

    return dialogWrapper;
  };

  Drupal.theme.dialogHeader = (title, closeText) => {
    const dialogHeaderWrapper = document.createElement('div');
    dialogHeaderWrapper.classList.add('drupal-dialog__header');

    if (title) {
      dialogHeaderWrapper.insertAdjacentHTML(
        'beforeend',
        `<h4 class="drupal-dialog__title">${title}</h4>`,
      );
    }

    const button = document.createElement('button');
    button.innerText = Drupal.t(closeText ?? 'Close');
    button.classList.add('drupal-dialog__close');
    button.addEventListener('click', () => {
      button.dispatchEvent(
        new CustomEvent('dialog-close', {
          bubbles: true,
        }),
      );
    });
    dialogHeaderWrapper.append(button);

    return dialogHeaderWrapper;
  };

  Drupal.theme.dialogContent = (content: HTMLElement): HTMLElement => {
    const dialogContentWrapper = document.createElement('div');
    dialogContentWrapper.classList.add('drupal-dialog__content');
    dialogContentWrapper.appendChild(content);
    return dialogContentWrapper;
  };

  Drupal.theme.dialogButtons = (
    buttons,
  ) => {
    const dialogButtonsWrapper = document.createElement('div');
    dialogButtonsWrapper.classList.add('drupal-dialog__buttons');

    if (Array.isArray(buttons)) {
      // Case where buttons is an array of DialogButtonOptions
      buttons.forEach((button) => {
        const buttonElement = document.createElement('button');
        buttonElement.textContent = button.text ?? '';
        if (button.class) {
          buttonElement.classList.add(...button.class.split(' '));
        }
        if (button.click) {
          buttonElement.addEventListener(
            'click',
            button.click as EventListener,
          );
        }
        dialogButtonsWrapper.appendChild(buttonElement);
      });
    } else if (typeof buttons === 'object' && buttons !== null) {
      // Case where buttons is an object with buttonText and click handlers
      Object.keys(buttons).forEach((buttonText) => {
        const buttonElement = document.createElement('button');
        buttonElement.textContent = buttonText;
        buttonElement.addEventListener(
          'click',
          buttons[buttonText] as EventListener,
        );
        dialogButtonsWrapper.appendChild(buttonElement);
      });
    }

    return dialogButtonsWrapper;
  };
})(window.Drupal);
